@@ -1,4 +1,4 @@
-/* $Id: board.cc,v 1.118 2007/01/20 23:28:57 bergo Exp $ */
+/* $Id: board.cc,v 1.119 2007/01/31 03:55:45 bergo Exp $ */
 
 /*
 
@@ -125,10 +125,6 @@ Board::Board() : WidgetProxy() {
                       (GtkSignalFunc) board_motion_event,
 		      (gpointer) this);
 
-  #ifdef WITH_DGT_BOARD
-    dgtSetBoard(this);
-  #endif
-
   gshow(widget);
 }
 
