@@ -18,10 +18,10 @@
 #define HAVE_MATH_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_SOCKET_H 1
-#define HAVE_NETDB_H 1
-#define HAVE_NETINET_IN_H 1
-#define HAVE_ARPA_INET_H 1
+#define HAVE_BSDBUGSYS_SOCKET_H 1
+#define HAVE_BSDBUGNETDB_H 1
+#define HAVE_BSDBUGNETINET_IN_H 1
+#define HAVE_BSDBUGARPA_INET_H 1
 #define HAVE_IOSTREAM 1
 #define HAVE_DEQUE 1
 #define HAVE_LIST 1
@@ -31,6 +31,7 @@
 #define HAVE_STRINGS_H 1
 #define HAVE_SYS_SOUNDCARD_H 1
 #undef HAVE_SYS_AUDIOIO_H
+#define HAVE_LINUX_JOYSTICK_H 1
 #define HAVE_IPPROTO_TCP_ON_IN_H 1
 #undef HAVE_TCP_NODELAY_ON_IN_H
 #undef HAVE_SOL_TCP_ON_IN_H
@@ -42,11 +43,9 @@
 #define USE_IPPROTO_TCP 1
 #define HAVE_GTK_GTK_H 1
 #define HAVE_GDK_GDKKEYSYMS_H 1
-#define HAVE_GDK_IMLIB_H 1
-#define HAVE_X11_XLIB_H 1
 #define DATADIR "/usr/local/share"
 #define EBOARD_PREFIX "/usr/local"
-#define VERSION "0.9.5"
+#define VERSION "1.0.4"
 #define ENABLE_NLS 1
 
 #endif
