@@ -1,4 +1,4 @@
-/* $Id: dlg_prefs.cc,v 1.48 2007/01/20 23:28:57 bergo Exp $ */
+/* $Id: dlg_prefs.cc,v 1.49 2007/02/05 19:37:56 bergo Exp $ */
 
 /*
 
@@ -51,6 +51,9 @@ char * PreferencesDialog::FontSample[NFONTS] = {
 PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   GtkWidget *v,*hs,*ok,*apply,*cancel,*bhb,*nb;
 
+  // scroll containers for tabs
+  GtkWidget *scr[7]; // ui, ics, colors, fonts, sounds, autosave, joystick
+
   // gui
   GtkWidget *uil,*uiv,*uih,*tfr,*tr[4],*tv,*uih3,*uih4,*uih5;
   GSList *tl;
@@ -100,7 +103,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   jsval[4] = global.JSNextTabButton;
   jstate = -1;
 
-  gtk_window_set_default_size(GTK_WINDOW(widget),450,300);
+  gtk_window_set_default_size(GTK_WINDOW(widget),600,480);
 
   v=gtk_vbox_new(FALSE,0);
   gtk_container_add(GTK_CONTAINER(widget),v);
@@ -118,7 +121,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   tfr=gtk_frame_new(_("Tab Position"));
   gtk_box_pack_start(GTK_BOX(uiv),tfr,FALSE,FALSE,4);
   gtk_frame_set_shadow_type(GTK_FRAME(tfr),GTK_SHADOW_ETCHED_IN);
-  tv=gtk_vbox_new(FALSE,2);
+  tv=gtk_hbox_new(FALSE,2);
 
   tr[0]=gtk_radio_button_new_with_label(0,_("Right"));
   tl=gtk_radio_button_group(GTK_RADIO_BUTTON(tr[0]));
@@ -173,9 +176,10 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   gtset(GTK_TOGGLE_BUTTON(dhsb), global.DrawHouseStock?1:0);
   gtset(GTK_TOGGLE_BUTTON(aqbar), global.ShowQuickbar?1:0);
 
+  scr[0] = scrollBox(uiv);
   Gtk::show(tv, tfr, uiv, uil, NULL);
 
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),uiv,uil);
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[0],uil);
   gtset(GTK_TOGGLE_BUTTON(tr[global.TabPos]), TRUE);
 
   // ics ===============================================================================
@@ -249,12 +253,14 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
 
   gtk_box_pack_start(GTK_BOX(icv),ict1,FALSE,FALSE,2);
 
+  scr[1] = scrollBox(icv);
   Gtk::show(icl1, sbacke, icl2, lowtime, icl3, ict1,
 	    ifr1, ifr2, ifv1, ifv2,
 	    icl, showratb, autologb, /*allob[0], allob[1],*/
 	    sgb, chsb, coct, wget, hsb, icv, NULL);
-
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),icv,icl);
+  
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[1],icl);
+  
   gtset(GTK_TOGGLE_BUTTON(showratb), global.ShowRating?1:0);
   gtset(GTK_TOGGLE_BUTTON(autologb), global.FicsAutoLogin?1:0);
   /*
@@ -310,8 +316,10 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   tcdef=gtk_button_new_with_label(_("Revert to Defaults"));
   gtk_box_pack_start(GTK_BOX(tcv2),tcdef,FALSE,FALSE,4);
 
+  scr[2] = scrollBox(tch);
   Gtk::show(preview->widget, tcdef, tch, tcv, tcv2, tcl, NULL);
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),tch,tcl);
+
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[2],tcl);
 
   gtk_signal_connect(GTK_OBJECT(tcdef),"clicked",
 		     GTK_SIGNAL_FUNC(prefs_defcolor),(gpointer)this);
@@ -367,8 +375,10 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
     efont[i]=fn[i];
     xfont[i]=fb[i];
   }
+
+  scr[3] = scrollBox(fv);
   Gtk::show(ft,fv,fl,NULL);
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),fv,fl);
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[3],fl);
 
   gtk_signal_connect(GTK_OBJECT(frv),"clicked",
 		     GTK_SIGNAL_FUNC(prefs_frevert),(gpointer)this);
@@ -442,8 +452,10 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
     gtk_signal_connect(GTK_OBJECT(sndedit[i]),"clicked",
 		       GTK_SIGNAL_FUNC(prefs_sndedit), (gpointer) this);
   }
+
+  scr[4] = scrollBox(sv);
   Gtk::show(zt,zv,zf,sv,sl,zl,NULL);
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),sv,sl);
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[4],sl);
 
   // autosave ========================================================================
 
@@ -467,8 +479,10 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   gtk_box_pack_start(GTK_BOX(gh),gll,FALSE,FALSE,4);
   gtk_box_pack_start(GTK_BOX(gh),afn,TRUE,TRUE,4);
 
+  scr[5] = scrollBox(gv);
+  
   Gtk::show(gv,gh,gl,gll,asp,aso,afn,NULL);
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),gv,gl);
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[5],gl);
 
   // joystick ===========================================================
 
@@ -506,8 +520,10 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   gtk_box_pack_start(GTK_BOX(jh2),jctl,FALSE,FALSE,4);
   gtk_container_add(GTK_CONTAINER(jf),jv);
 
+  scr[6] = scrollBox(jv2);
+  
   Gtk::show(jv,jl,jcl,jctl,jh1,jh2,jf,jv2,jh3,jh4,jl2,jmode,jspeed,NULL);
-  gtk_notebook_append_page(GTK_NOTEBOOK(nb),jv2,jl);
+  gtk_notebook_append_page(GTK_NOTEBOOK(nb),scr[6],jl);
   formatJoystickDescription();
 
   gtset(GTK_TOGGLE_BUTTON(jmode), global.JSMode?1:0);
