@@ -1,4 +1,4 @@
-/* $Id: global.cc,v 1.93 2007/01/20 23:28:57 bergo Exp $ */
+/* $Id: global.cc,v 1.94 2007/02/05 14:16:20 pierrebou Exp $ */
 
 /*
 
@@ -35,6 +35,7 @@
 #include <sys/wait.h>
 #include <time.h>
 #include <signal.h>
+#include <dlfcn.h>
 
 #define GLOBAL_CC 1
 
@@ -50,6 +51,11 @@
 #include "pieces.h"
 #include "eboard.h"
 
+
+/* Global variables needed to cleanly close the driver */
+extern int (*dgtnixClose)();
+extern bool DgtInit;
+extern void *dgtnix_dll_handle;
 Global global;
 
 // stream ops
@@ -670,6 +676,12 @@ void Global::WrappedMainQuit() {
   }
   QuitPending=0;
   signal(SIGCHLD,SIG_DFL); // prevent the crash reported by gcp
+  /* close dgtnix driver and dll */
+  if(DgtInit)
+    {
+      dgtnixClose();
+      dlclose(dgtnix_dll_handle);
+    }
   gtk_main_quit();
 }
 
