@@ -1,4 +1,4 @@
-/* $Id: help.cc,v 1.31 2007/01/20 15:58:43 bergo Exp $ */
+/* $Id: help.cc,v 1.32 2007/02/05 19:37:56 bergo Exp $ */
 
 /*
 
@@ -107,7 +107,7 @@ namespace Help {
   }
 
   KeysDialog::KeysDialog() : ModalDialog(N_("Help: Keys")) {
-    GtkWidget *v,*label,*bhb,*hs,*ok;
+    GtkWidget *v,*label,*lbs,*bhb,*hs,*ok;
     char z[1024];
     
     v=gtk_vbox_new(FALSE,4);
@@ -134,10 +134,11 @@ namespace Help {
 	   "In main window's input box:\n"\
 	   ".. entering %prefix text will set the chat prefix to text.\n"\
 	   ".. entering %do scriptname will run scriptname."));
-    
+
     label=gtk_label_new(z);
     gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start(GTK_BOX(v),label,TRUE,TRUE,4);
+    lbs = scrollBox(label);
+    gtk_box_pack_start(GTK_BOX(v),lbs,TRUE,TRUE,4);
     
     hs=gtk_hseparator_new();
     gtk_box_pack_start(GTK_BOX(v),hs,FALSE,FALSE,4);
@@ -153,7 +154,7 @@ namespace Help {
     gtk_box_pack_start(GTK_BOX(bhb),ok,TRUE,TRUE,0);
     
     gtk_widget_grab_default(ok);
-    
+    gtk_window_set_default_size(GTK_WINDOW(widget),450, 450);
     Gtk::show(ok,bhb,hs,label,v,NULL);
     setDismiss(GTK_OBJECT(ok),"clicked");
   }
@@ -296,9 +297,9 @@ namespace Help {
 
 
   GettingStarted::GettingStarted() : NonModalDialog(N_("Help: Getting Started ")) {
-    GtkWidget *v, *bhb, *ok, *fr;
+    GtkWidget *v, *ts, *bhb, *ok, *fr;
 
-    gtk_window_set_default_size(GTK_WINDOW(widget),620,520);
+    gtk_window_set_default_size(GTK_WINDOW(widget),620,560);
     v=gtk_vbox_new(FALSE,4);
     gtk_container_add(GTK_CONTAINER(widget),v);
 
@@ -306,9 +307,11 @@ namespace Help {
     gtk_frame_set_shadow_type(GTK_FRAME(fr),GTK_SHADOW_ETCHED_IN);
     gtk_box_pack_start(GTK_BOX(v),fr,TRUE,TRUE,0);
 
+    
     text=gtk_text_view_new();
     g_object_set(G_OBJECT(text),"cursor-visible",FALSE,NULL);
-    gtk_container_add(GTK_CONTAINER(fr),text);
+    ts = scrollBox(text);
+    gtk_container_add(GTK_CONTAINER(fr),ts);
 
     bhb=gtk_hbutton_box_new();
     gtk_button_box_set_layout(GTK_BUTTON_BOX(bhb), GTK_BUTTONBOX_END);
