@@ -1,4 +1,4 @@
-/* $Id: network.cc,v 1.48 2007/01/20 15:58:43 bergo Exp $ */
+/* $Id: network.cc,v 1.49 2007/02/05 20:15:16 bergo Exp $ */
 
 /*
 
@@ -612,7 +612,8 @@ PipeConnection::PipeConnection(char *host,int port,
   else
     g_strlcpy(z,helperbin,256);
 
-  eff.find(z,HelperBin);
+  if (!eff.find(z,HelperBin))
+    HelperBin[0] = 0;
 }
 
 PipeConnection::~PipeConnection() {
@@ -659,6 +660,11 @@ int PipeConnection::open() {
   for(i=0;i<6;i++)
     arguments[i]=0;
 
+  if (HelperBin[0]==0) {
+    snprintf(errorMessage,128,_("Helper program not found"));
+    return -1;
+  }
+
   switch(opmode) {
   case 0:
     for(i=0;i<args.size();i++)
