@@ -1,4 +1,4 @@
-/* $Id: ntext.cc,v 1.17 2007/01/20 21:55:00 bergo Exp $ */
+/* $Id: ntext.cc,v 1.19 2007/05/23 18:45:07 bergo Exp $ */
 
 /*
 
@@ -441,6 +441,8 @@ void NText::discardLines(int n) {
   if (n > (signed) lines.size()) n = lines.size();
   if (!n) return;
 
+  if (!xlines.size()) return;
+
   top  = (int) (vsa->value);
   top  = xlines[top]->Src;
   top -= n;
@@ -742,7 +744,7 @@ gboolean ntext_configure(GtkWidget *widget, GdkEventConfigure *ee,
 	ox += pw;
 	L->setColor(fl->Color);
 
-	if (o2+1 != fl->NBytes - 1)
+	if (o2+1 != fl->NBytes)
 	  L->drawString(lb+ox,tb+fh*i,0,fl->Text+o2+1);
       }
     }
