@@ -1,4 +1,4 @@
-/* $Id: proto_xboard.cc,v 1.49 2007/01/21 13:05:34 bergo Exp $ */
+/* $Id: proto_xboard.cc,v 1.51 2007/02/05 20:19:19 bergo Exp $ */
 
 /*
 
@@ -504,8 +504,14 @@ int XBoardProtocol::loadEngine() {
       dumpGame();
     }
   }
-
+  
   global.status->setText(_("Failed to run engine."),30);
+  
+  global.output->append(_("Failed to run engine."),
+			global.Colors.TextBright,IM_NORMAL);
+  global.output->append(_("Failed command line:"),
+			global.Colors.TextBright,IM_NORMAL);
+  global.output->append(FullCommand, global.Colors.TextBright,IM_NORMAL);
   delete link;
   return 0;
 }
